@@ -58,16 +58,13 @@
 #' 
 #' \itemize{
 #' 
-#' \item{\code{0} --- }
-#' {No derivatives; consistent with moving average}
+#' \item \code{0} --- No derivatives; consistent with moving average
 #' 
-#' \item{\code{1} --- }
-#' {First-order derivatives; interpretated as "velocity" or 
-#' rate of change over time}
+#' \item \code{1} --- First-order derivatives; interpreted as "velocity" or 
+#' rate of change over time
 #' 
-#' \item{\code{2} --- }
-#' {Second-order derivatives; interpreted as "acceleration" or
-#' rate of the rate of change over time}
+#' \item \code{2} --- Second-order derivatives; interpreted as "acceleration" or
+#' rate of the rate of change over time
 #' 
 #' }
 #' 
@@ -78,17 +75,14 @@
 #'
 #' \itemize{
 #'
-#' \item{\code{"individual"} --- }
-#' {Estimates \code{\link[EGAnet]{EGA}} for each individual in \code{data}
-#' (intraindividual structure; requires an \code{"ID"} column, see \code{data})}
+#' \item \code{"individual"} --- Estimates \code{\link[EGAnet]{EGA}} for each individual in \code{data}
+#' (intraindividual structure; requires an \code{"ID"} column, see \code{data})
 #' 
-#' \item{\code{"group"} --- }
-#' {Estimates \code{\link[EGAnet]{EGA}} for each group in \code{data}
-#' (group structure; requires a \code{"Group"} column, see \code{data})}
+#' \item \code{"group"} --- Estimates \code{\link[EGAnet]{EGA}} for each group in \code{data}
+#' (group structure; requires a \code{"Group"} column, see \code{data})
 #' 
-#' \item{\code{"population"} --- }
-#' {Estimates \code{\link[EGAnet]{EGA}} across all \code{data}
-#' (interindividual structure)}
+#' \item \code{"population"} --- Estimates \code{\link[EGAnet]{EGA}} across all \code{data}
+#' (interindividual structure)
 #'
 #' }
 #'
@@ -99,21 +93,21 @@
 #' 
 #' \itemize{
 #' 
-#' \item{\code{"auto"} --- }
-#' {Automatically computes appropriate correlations for
+#' \item \code{"auto"} --- Automatically computes appropriate correlations for
 #' the data using Pearson's for continuous, polychoric for ordinal,
 #' tetrachoric for binary, and polyserial/biserial for ordinal/binary with
 #' continuous. To change the number of categories that are considered
 #' ordinal, use \code{ordinal.categories}
-#' (see \code{\link[EGAnet]{polychoric.matrix}} for more details)}
+#' (see \code{\link[EGAnet]{polychoric.matrix}} for more details)
 #' 
-#' \item{\code{"pearson"} --- }
-#' {Pearson's correlation is computed for all variables regardless of
-#' categories}
+#' \item \code{"cor_auto"} --- Uses \code{\link[qgraph]{cor_auto}} to compute correlations. 
+#' Arguments can be passed along to the function
 #' 
-#' \item{\code{"spearman"} --- }
-#' {Spearman's rank-order correlation is computed for all variables
-#' regardless of categories}
+#' \item \code{"pearson"} --- Pearson's correlation is computed for all 
+#' variables regardless of categories
+#' 
+#' \item \code{"spearman"} --- Spearman's rank-order correlation is computed 
+#' for all variables regardless of categories
 #' 
 #' }
 #' 
@@ -127,12 +121,10 @@
 #' 
 #' \itemize{
 #' 
-#' \item{\code{"pairwise"} --- }
-#' {Computes correlation for all available cases between
-#' two variables}
+#' \item \code{"pairwise"} --- Computes correlation for all available cases between
+#' two variables
 #' 
-#' \item{\code{"listwise"} --- }
-#' {Computes correlation for all complete cases in the dataset}
+#' \item \code{"listwise"} --- Computes correlation for all complete cases in the dataset
 #' 
 #' }
 #' 
@@ -142,19 +134,16 @@
 #' 
 #' \itemize{
 #' 
-#' \item{\code{"BGGM"} --- }
-#' {Computes the Bayesian Gaussian Graphical Model.
+#' \item \code{"BGGM"} --- Computes the Bayesian Gaussian Graphical Model.
 #' Set argument \code{ordinal.categories} to determine
 #' levels allowed for a variable to be considered ordinal.
-#' See \code{\link[BGGM]{estimate}} for more details}
+#' See \code{?BGGM::estimate} for more details
 #' 
-#' \item{\code{"glasso"} --- }
-#' {Computes the GLASSO with EBIC model selection.
-#' See \code{\link[EGAnet]{EBICglasso.qgraph}} for more details}
+#' \item \code{"glasso"} --- Computes the GLASSO with EBIC model selection.
+#' See \code{\link[EGAnet]{EBICglasso.qgraph}} for more details
 #' 
-#' \item{\code{"TMFG"} --- }
-#' {Computes the TMFG method.
-#' See \code{\link[EGAnet]{TMFG}} for more details}
+#' \item \code{"TMFG"} --- Computes the TMFG method.
+#' See \code{\link[EGAnet]{TMFG}} for more details
 #' 
 #' }
 #' 
@@ -166,18 +155,15 @@
 #' 
 #' \itemize{
 #'
-#' \item{\code{"leiden"} --- }
-#' {See \code{\link[igraph]{cluster_leiden}} for more details}
+#' \item \code{"leiden"} --- See \code{\link[igraph]{cluster_leiden}} for more details
 #' 
-#' \item{\code{"louvain"} --- }
-#' {By default, \code{"louvain"} will implement the Louvain algorithm using 
+#' \item \code{"louvain"} --- By default, \code{"louvain"} will implement the Louvain algorithm using 
 #' the consensus clustering method (see \code{\link[EGAnet]{community.consensus}} 
 #' for more information). This function will implement
 #' \code{consensus.method = "most_common"} and \code{consensus.iter = 1000} 
-#' unless specified otherwise}
+#' unless specified otherwise
 #' 
-#' \item{\code{"walktrap"} --- }
-#' {See \code{\link[igraph]{cluster_walktrap}} for more details}
+#' \item \code{"walktrap"} --- See \code{\link[igraph]{cluster_walktrap}} for more details
 #' 
 #' }
 #'
@@ -188,28 +174,25 @@
 #' 
 #' \itemize{
 #'
-#' \item{\code{"expand"} --- }
-#' {Expands the correlation matrix with four variables correlated 0.50.
+#' \item \code{"expand"} --- Expands the correlation matrix with four variables correlated 0.50.
 #' If number of dimension returns 2 or less in check, then the data 
 #' are unidimensional; otherwise, regular EGA with no matrix
 #' expansion is used. This method was used in the Golino et al.'s (2020)
-#' \emph{Psychological Methods} simulation}
+#' \emph{Psychological Methods} simulation
 #'
-#' \item{\code{"LE"} --- }
-#' {Applies the Leading Eigenvector algorithm
+#' \item \code{"LE"} --- Applies the Leading Eigenvector algorithm
 #' (\code{\link[igraph]{cluster_leading_eigen}})
 #' on the empirical correlation matrix. If the number of dimensions is 1,
 #' then the Leading Eigenvector solution is used; otherwise, regular EGA
 #' is used. This method was used in the Christensen et al.'s (2023) 
-#' \emph{Behavior Research Methods} simulation}
+#' \emph{Behavior Research Methods} simulation
 #' 
-#' \item{\code{"louvain"} --- }
-#' {Applies the Louvain algorithm (\code{\link[igraph]{cluster_louvain}})
+#' \item \code{"louvain"} --- Applies the Louvain algorithm (\code{\link[igraph]{cluster_louvain}})
 #' on the empirical correlation matrix. If the number of dimensions is 1, 
 #' then the Louvain solution is used; otherwise, regular EGA is used. 
 #' This method was validated Christensen's (2022) \emph{PsyArXiv} simulation.
 #' Consensus clustering can be used by specifying either
-#' \code{"consensus.method"} or \code{"consensus.iter"}}
+#' \code{"consensus.method"} or \code{"consensus.iter"}
 #' 
 #' }
 #' 
@@ -240,15 +223,13 @@
 #' 
 #' \itemize{
 #' 
-#' \item{\code{Estimates} --- }
-#' {A list the length of the unique IDs containing
-#' data frames of zero- to second-order derivatives for each ID in \code{data}}
+#' \item \code{Estimates} --- A list the length of the unique IDs containing
+#' data frames of zero- to second-order derivatives for each ID in \code{data}
 #' 
-#' \item{\code{EstimatesDF} --- }
-#' {A data frame of derivatives across all IDs containing
+#' \item \code{EstimatesDF} --- A data frame of derivatives across all IDs containing
 #' columns of the zero- to second-order derivatives as well as \code{id} and
 #' \code{group} variables (\code{group} is automatically set to \code{1}
-#' for all if no \code{group} is provided)}
+#' for all if no \code{group} is provided)
 #' 
 #' }
 #' 
@@ -258,17 +239,14 @@
 #' 
 #' \itemize{
 #' 
-#' \item{\code{population} --- }
-#' {If \code{level} includes \code{"populaton"}, then
-#' the \code{\link[EGAnet]{EGA}} results for the entire sample}
+#' \item \code{population} --- If \code{level} includes \code{"populaton"}, then
+#' the \code{\link[EGAnet]{EGA}} results for the entire sample
 #' 
-#' \item{\code{group} --- }
-#' {If \code{level} includes \code{"group"}, then
-#' a list containing the \code{\link[EGAnet]{EGA}} results for each \code{group}}
+#' \item \code{group} --- If \code{level} includes \code{"group"}, then
+#' a list containing the \code{\link[EGAnet]{EGA}} results for each \code{group}
 #' 
-#' \item{\code{individual} --- }
-#' {If \code{level} includes \code{"individual"}, then
-#' a list containing the \code{\link[EGAnet]{EGA}} results for each \code{id}}
+#' \item \code{individual} --- If \code{level} includes \code{"individual"}, then
+#' a list containing the \code{\link[EGAnet]{EGA}} results for each \code{id}
 #' 
 #' }
 #' 
@@ -353,14 +331,14 @@
 #' @export
 #' 
 # dynEGA ----
-# Updated 09.08.2023
+# Updated 24.10.2023
 dynEGA <- function(
     # `dynEGA` arguments
     data,  id = NULL, group = NULL,
     n.embed = 5, tau = 1, delta = 1, use.derivatives = 1,
     level = c("individual", "group", "population"),
     # `EGA` arguments
-    corr = c("auto", "pearson", "spearman"),
+    corr = c("auto", "cor_auto", "pearson", "spearman"),
     na.data = c("pairwise", "listwise"),
     model = c("BGGM", "glasso", "TMFG"),  
     algorithm = c("leiden", "louvain", "walktrap"),
@@ -369,8 +347,7 @@ dynEGA <- function(
 ){
   
   # Check for missing arguments (argument, default, function)
-  corr <- set_default(corr, "auto", c("auto", "cor_auto", "pearson", "spearman"))
-  corr <- swiftelse(corr == "cor_auto", "auto", corr) # deprecate `cor_auto`
+  corr <- set_default(corr, "auto", dynEGA)
   na.data <- set_default(na.data, "pairwise", auto.correlate)
   model <- set_default(model, "glasso", network.estimation)
   algorithm <- set_default(algorithm, "walktrap", community.detection)
@@ -782,7 +759,7 @@ print.dynEGA.Group <- function(x, ...)
 
 #' @exportS3Method 
 # S3 Print Method (Individual) ----
-# Updated 22.07.2023
+# Updated 11.10.2023
 print.dynEGA.Individual <- function(x, ...)
 {
   
@@ -805,12 +782,6 @@ print.dynEGA.Individual <- function(x, ...)
   # Add line break
   cat("\n")
   
-  # Print community detection
-  print(x[[1]]$wc, boot = TRUE)
-  
-  # Add line break
-  cat("\n")
-  
   # Get unidimensional attributes
   unidimensional_attributes <- attr(x[[1]], "unidimensional")
   
@@ -1247,11 +1218,11 @@ plot.dynEGA.Individual <- function(x, base = 1, id = NULL, ...)
 
 #' @noRd
 # Get ID from data ----
-# Updated 04.078.2023
+# Updated 28.09.2023
 get_ID <- function(data, id, level, variable_names, dimensions)
 {
   
-  # First, check for 'id' in variable names
+  # First, check for 'id' in variable names (revert)
   if("id" %in% variable_names){
     
     # Get 'id' from data if already listed as a column
@@ -1263,16 +1234,18 @@ get_ID <- function(data, id, level, variable_names, dimensions)
     # Remove 'id' from data
     data <- data[,-id]
     
-  }else if(is.null(id) & "individual" %in% level){
+  }else if(is.null(id)){
     
     # Set id to be `1` (same as "population")
     ID <- rep(1, dim(data)[1])
     
     # Send warning
-    warning(
-      "'level' included \"individual\" but no 'id' was provided. Setting all 'id' to `1` or same as level = \"population\"",
-      call. = FALSE
-    )
+    if("individual" %in% level){
+      warning(
+        "'level' included \"individual\" but no 'id' was provided. Setting all 'id' to `1` or same as level = \"population\"",
+        call. = FALSE
+      )
+    }
     
   }else{ # Otherwise, check for proper IDs
     
@@ -1308,22 +1281,17 @@ get_ID <- function(data, id, level, variable_names, dimensions)
   }
   
   # Return list
-  return(
-    list(
-      data = data,
-      ID = ID
-    )
-  )
+  return(list(data = data, ID = ID))
   
 }
 
 #' @noRd
 # Get Group from data ----
-# Updated 04.08.2023
+# Updated 28.09.2023
 get_Group <- function(data, group, level, variable_names, dimensions)
 {
   
-  # First, check for 'id' in variable names
+  # First, check for 'group' in variable names (revert)
   if("group" %in% variable_names){
     
     # Get 'group' from data if already listed as a column
@@ -1382,12 +1350,7 @@ get_Group <- function(data, group, level, variable_names, dimensions)
   }
   
   # Return list
-  return(
-    list(
-      data = data,
-      Group = Group
-    )
-  )
+  return(list(data = data, Group = Group))
   
 }
 
