@@ -58,16 +58,13 @@
 #'
 #' \itemize{
 #'
-#' \item{\code{"none"} --- }
-#' {Default. No imputation is performed}
+#' \item \code{"none"} --- Default. No imputation is performed
 #'
-#' \item{\code{"mean"} --- }
-#' {The mean value of each variable is used to replace missing data
-#' for that variable}
+#' \item \code{"mean"} --- The mean value of each variable is used to replace missing data
+#' for that variable
 #'
-#' \item{\code{"median"} --- }
-#' {The median value of each variable is used to replace missing data
-#' for that variable}
+#' \item \code{"median"} --- The median value of each variable is used to replace missing data
+#' for that variable
 #'
 #' }
 #'
@@ -78,21 +75,21 @@
 #' 
 #' \itemize{
 #' 
-#' \item{\code{"auto"} --- }
-#' {Automatically computes appropriate correlations for
+#' \item \code{"auto"} --- Automatically computes appropriate correlations for
 #' the data using Pearson's for continuous, polychoric for ordinal,
 #' tetrachoric for binary, and polyserial/biserial for ordinal/binary with
 #' continuous. To change the number of categories that are considered
 #' ordinal, use \code{ordinal.categories}
-#' (see \code{\link[EGAnet]{polychoric.matrix}} for more details)}
+#' (see \code{\link[EGAnet]{polychoric.matrix}} for more details)
 #' 
-#' \item{\code{"pearson"} --- }
-#' {Pearson's correlation is computed for all variables regardless of
-#' categories}
+#' \item \code{"cor_auto"} --- Uses \code{\link[qgraph]{cor_auto}} to compute correlations. 
+#' Arguments can be passed along to the function
 #' 
-#' \item{\code{"spearman"} --- }
-#' {Spearman's rank-order correlation is computed for all variables
-#' regardless of categories}
+#' \item \code{"pearson"} --- Pearson's correlation is computed for all 
+#' variables regardless of categories
+#' 
+#' \item \code{"spearman"} --- Spearman's rank-order correlation is computed 
+#' for all variables regardless of categories
 #' 
 #' }
 #' 
@@ -106,12 +103,10 @@
 #' 
 #' \itemize{
 #' 
-#' \item{\code{"pairwise"} --- }
-#' {Computes correlation for all available cases between
-#' two variables}
+#' \item \code{"pairwise"} --- Computes correlation for all available cases between
+#' two variables
 #' 
-#' \item{\code{"listwise"} --- }
-#' {Computes correlation for all complete cases in the dataset}
+#' \item \code{"listwise"} --- Computes correlation for all complete cases in the dataset
 #' 
 #' }
 #' 
@@ -121,19 +116,16 @@
 #' 
 #' \itemize{
 #' 
-#' \item{\code{"BGGM"} --- }
-#' {Computes the Bayesian Gaussian Graphical Model.
+#' \item \code{"BGGM"} --- Computes the Bayesian Gaussian Graphical Model.
 #' Set argument \code{ordinal.categories} to determine
 #' levels allowed for a variable to be considered ordinal.
-#' See \code{\link[BGGM]{estimate}} for more details}
+#' See \code{?BGGM::estimate} for more details
 #' 
-#' \item{\code{"glasso"} --- }
-#' {Computes the GLASSO with EBIC model selection.
-#' See \code{\link[EGAnet]{EBICglasso.qgraph}} for more details}
+#' \item \code{"glasso"} --- Computes the GLASSO with EBIC model selection.
+#' See \code{\link[EGAnet]{EBICglasso.qgraph}} for more details
 #' 
-#' \item{\code{"TMFG"} --- }
-#' {Computes the TMFG method.
-#' See \code{\link[EGAnet]{TMFG}} for more details}
+#' \item \code{"TMFG"} --- Computes the TMFG method.
+#' See \code{\link[EGAnet]{TMFG}} for more details
 #' 
 #' }
 #'
@@ -156,18 +148,15 @@
 #' 
 #' \itemize{
 #'
-#' \item{\code{"leiden"} --- }
-#' {See \code{\link[igraph]{cluster_leiden}} for more details}
+#' \item \code{"leiden"} --- See \code{\link[igraph]{cluster_leiden}} for more details
 #' 
-#' \item{\code{"louvain"} --- }
-#' {By default, \code{"louvain"} will implement the Louvain algorithm using 
+#' \item \code{"louvain"} --- By default, \code{"louvain"} will implement the Louvain algorithm using 
 #' the consensus clustering method (see \code{\link[EGAnet]{community.consensus}} 
 #' for more information). This function will implement
 #' \code{consensus.method = "most_common"} and \code{consensus.iter = 1000} 
-#' unless specified otherwise}
+#' unless specified otherwise
 #' 
-#' \item{\code{"walktrap"} --- }
-#' {See \code{\link[igraph]{cluster_walktrap}} for more details}
+#' \item \code{"walktrap"} --- See \code{\link[igraph]{cluster_walktrap}} for more details
 #' 
 #' }
 #' 
@@ -182,28 +171,25 @@
 #' 
 #' \itemize{
 #'
-#' \item{\code{expand} --- }
-#' {Expands the correlation matrix with four variables correlated 0.50.
+#' \item \code{"expand"} --- Expands the correlation matrix with four variables correlated 0.50.
 #' If number of dimension returns 2 or less in check, then the data 
 #' are unidimensional; otherwise, regular EGA with no matrix
 #' expansion is used. This method was used in the Golino et al.'s (2020)
-#' \emph{Psychological Methods} simulation}
+#' \emph{Psychological Methods} simulation
 #'
-#' \item{\code{LE} --- }
-#' {Applies the Leading Eigenvector algorithm
+#' \item \code{"LE"} --- Applies the Leading Eigenvector algorithm
 #' (\code{\link[igraph]{cluster_leading_eigen}})
 #' on the empirical correlation matrix. If the number of dimensions is 1,
 #' then the Leading Eigenvector solution is used; otherwise, regular EGA
 #' is used. This method was used in the Christensen et al.'s (2023) 
-#' \emph{Behavior Research Methods} simulation}
+#' \emph{Behavior Research Methods} simulation
 #' 
-#' \item{\code{louvain} --- }
-#' {Applies the Louvain algorithm (\code{\link[igraph]{cluster_louvain}})
+#' \item \code{"louvain"} --- Applies the Louvain algorithm (\code{\link[igraph]{cluster_louvain}})
 #' on the empirical correlation matrix. If the number of dimensions is 1, 
 #' then the Louvain solution is used; otherwise, regular EGA is used. 
 #' This method was validated Christensen's (2022) \emph{PsyArXiv} simulation.
 #' Consensus clustering can be used by specifying either
-#' \code{"consensus.method"} or \code{"consensus.iter"}}
+#' \code{"consensus.method"} or \code{"consensus.iter"}
 #' 
 #' }
 #'
@@ -286,7 +272,7 @@
 #' @export
 #'
 # Hierarchical EGA ----
-# Updated 09.08.2023
+# Updated 24.10.2023
 hierEGA <- function(
     data, 
     # `net.scores` arguments
@@ -295,7 +281,7 @@ hierEGA <- function(
     loading.structure = c("simple", "full"),
     impute = c("mean", "median", "none"),
     # `EGA` arguments
-    corr = c("auto", "pearson", "spearman"),
+    corr = c("auto", "cor_auto", "pearson", "spearman"),
     na.data = c("pairwise", "listwise"),
     model = c("BGGM", "glasso", "TMFG"),
     lower.algorithm = "louvain",
@@ -310,10 +296,10 @@ hierEGA <- function(
   experimental("hierEGA")
   
   # Argument errors (return data in case of tibble)
-  data <- hierEGA_errors(data, plot.EGA, verbose)
+  data <- hierEGA_errors(data, plot.EGA, verbose, ...)
   
   # Get ellipse arguments
-  ellipse <- list(...)
+  ellipse <- list(needs_usable = FALSE, ...)
   
   # Check for missing arguments (argument, default, function)
   ## `net.scores`
@@ -322,8 +308,7 @@ hierEGA <- function(
   loading.structure <- set_default(loading.structure, "simple", hierEGA)
   impute <- set_default(impute, "none", net.scores)
   ## `EGA`
-  corr <- set_default(corr, "auto", c("auto", "cor_auto", "pearson", "spearman"))
-  corr <- swiftelse(corr == "cor_auto", "auto", corr) # deprecate `cor_auto`
+  corr <- set_default(corr, "auto", hierEGA)
   na.data <- set_default(na.data, "pairwise", auto.correlate)
   model <- set_default(model, "glasso", network.estimation)
   uni.method <- set_default(uni.method, "louvain", community.unidimensional)
@@ -611,8 +596,8 @@ hierEGA <- function(
 
 #' @noRd
 # Argument errors ----
-# Updated 19.08.2023
-hierEGA_errors <- function(data, plot.EGA, verbose)
+# Updated 07.09.2023
+hierEGA_errors <- function(data, plot.EGA, verbose, ...)
 {
   
   # 'data' errors
@@ -631,8 +616,13 @@ hierEGA_errors <- function(data, plot.EGA, verbose)
   length_error(verbose, 1, "hierEGA")
   typeof_error(verbose, "logical", "hierEGA")
   
+  # Check for usable data
+  if(needs_usable(list(...))){
+    data <- usable_data(data, verbose)
+  }
+  
   # Return usable data in case of tibble
-  return(usable_data(data, verbose))
+  return(data)
   
 }
 
