@@ -281,7 +281,7 @@ net.loads <- function(
 
 #' @exportS3Method 
 # S3 Print Method
-# Updated 12.07.2023
+# Updated 08.10.2023
 print.net.loads <- function(x, ...)
 {
  
@@ -337,12 +337,14 @@ print.net.loads <- function(x, ...)
   )
   
   # Add message about minimum loadings
-  paste0(
-    "Standardized loadings >= |", format_decimal(minimum, 2),
-    "| are displayed. To change this 'minimum', use ",
-    "`print(net.loads_object, minimum = 0.10)`"
+  cat(
+    paste0(
+      "Standardized loadings >= |", format_decimal(minimum, 2),
+      "| are displayed. To change this 'minimum', use ",
+      "`print(net.loads_object, minimum = 0.10)`"
+    )
   )
-  
+
 }
 
 #' @exportS3Method 
@@ -444,7 +446,7 @@ obtain_signs <- function(target_network)
 
 #' @noRd
 # Experimental loadings ----
-# Updated 04.08.2023
+# Updated 05.09.2023
 experimental_loadings <- function(
     A, wc, nodes, node_names, 
     communities, unique_communities
@@ -480,10 +482,10 @@ experimental_loadings <- function(
     
   }
   
-  # Multiply the assigned loading matrix by 1.5
+  # Multiply the assigned loading matrix by 2
   # This computation is a vectorization of putting half
   # of a node's within-community strength on it's diagonal
-  loading_matrix <- loading_matrix * 1.5
+  loading_matrix <- loading_matrix * 2
   
   # Check for unidimensional structure
   if(communities > 1){
